# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.binding
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_list_entry_source import XListEntrySource as XListEntrySource_576b103c

class XListEntrySink(XInterface_8f010a43):
    """
    specifies support for indirect manipulation of a string list

    See Also:
        `API XListEntrySink <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XListEntrySink.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.binding'
    __ooo_full_ns__: str = 'com.sun.star.form.binding.XListEntrySink'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.binding.XListEntrySink'

    @abstractmethod
    def getListEntrySource(self) -> XListEntrySource_576b103c:
        """
        retrieves the current source for the list entries of the component.
        """
        ...
    @abstractmethod
    def setListEntrySource(self, Source: XListEntrySource_576b103c) -> None:
        """
        sets the new source for the list entries of the component
        
        The list represented by this component will be cleared, and initially filled with the entries from the new list source.
        """
        ...

__all__ = ['XListEntrySink']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from .x_sub_total_descriptor import XSubTotalDescriptor as XSubTotalDescriptor_19fd0ec6

class SubTotalDescriptor(XPropertySet_bc180bfa, XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XSubTotalDescriptor_19fd0ec6):
    """
    Service Class

    represents a description of how subtotals are created.
    
    The descriptor contains properties and a collection of subtotal fields which control the behavior of operation.

    See Also:
        `API SubTotalDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SubTotalDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BindFormatsToContent(self) -> bool:
        """
        specifies if cell formats are moved with the contents they belong to.
        """
        ...

    @abstractproperty
    def EnableSort(self) -> bool:
        """
        specifies if the contents of the fields will be sorted to groups while performing a subtotal operation.
        """
        ...

    @abstractproperty
    def EnableUserSortList(self) -> bool:
        """
        specifies if a user defined sorting list is used.
        """
        ...

    @abstractproperty
    def InsertPageBreaks(self) -> bool:
        """
        specifies if page breaks are inserted after each group change.
        """
        ...

    @abstractproperty
    def IsCaseSensitive(self) -> bool:
        """
        specifies if the case of letters is important when comparing entries.
        """
        ...

    @abstractproperty
    def MaxFieldCount(self) -> int:
        """
        returns the maximum number of subtotal fields the descriptor can hold.
        
        This read-only property indicates the maximum count of fields the current implementation supports.
        """
        ...

    @abstractproperty
    def SortAscending(self) -> bool:
        """
        specifies the sorting order if SubTotalDescriptor.EnableSort is set to TRUE.
        """
        ...

    @abstractproperty
    def UserSortListIndex(self) -> int:
        """
        specifies which user defined sorting list is used.
        
        This property is only used if SubTotalDescriptor.EnableUserSortList is TRUE.
        """
        ...


__all__ = ['SubTotalDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class PageStyleLayout(Enum):
    """
    Enum Class


    See Also:
        `API PageStyleLayout <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style.html#ae13f8c21c10b194207bb33f84a33d50f>`_
    """
    __ooo_ns__: str = "com.sun.star.style"
    __ooo_full_ns__: str = "com.sun.star.style.PageStyleLayout"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.style.PageStyleLayout"

    ALL = "ALL"
    """
    The page style is identically used for left and right pages.
    """
    LEFT = "LEFT"
    """
    set the horizontal alignment to the left margin from the container object
    
    The text range is left-aligned between the previous tabulator (or the left border, if none) and this tabulator.
    
    adjusted to the left border
    
    The page style is only used for left pages.
    """
    MIRRORED = "MIRRORED"
    """
    The page style is used unchanged for left pages and mirrored for right pages.
    """
    RIGHT = "RIGHT"
    """
    set the horizontal alignment to the right margin from the container object
    
    The text range is right-aligned between the previous tabulator (or the left border, if none) and this tabulator.
    
    adjusted to the right border
    
    The page style is only used for right pages.
    """

__all__ = ["PageStyleLayout"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
import uno
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08
from .x_data_pilot_member_results import XDataPilotMemberResults as XDataPilotMemberResults_56421045
from .x_members_supplier import XMembersSupplier as XMembersSupplier_efd10d98
if typing.TYPE_CHECKING:
    from .general_function import GeneralFunction as GeneralFunction_e2280d25

class DataPilotSourceLevel(XPropertySet_bc180bfa, XNamed_a6520b08, XDataPilotMemberResults_56421045, XMembersSupplier_efd10d98):
    """
    Service Class

    represents a level in a data pilot source hierarchy.
    
    **since**
    
        LibreOffice 5.3

    See Also:
        `API DataPilotSourceLevel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceLevel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotSourceLevel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SubTotals(self) -> typing.Tuple[GeneralFunction_e2280d25, ...]:
        """
        specifies the subtotals that are inserted for the level.
        
        The subtotals are calculated with the members of this level.
        """
        ...

    @abstractproperty
    def SubTotals2(self) -> uno.ByteSequence:
        """
        specifies the subtotals that are inserted for the level.
        
        The subtotals are calculated with the members of this level.
        
        **since**
        
            LibreOffice 5.3
        """
        ...

    @abstractproperty
    def ShowEmpty(self) -> bool:
        """
        specifies whether empty members are shown.
        """
        ...


__all__ = ['DataPilotSourceLevel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ..container.x_container import XContainer as XContainer_d6fb0cc6

class XAnimatedImages(XContainer_d6fb0cc6):
    """
    allows administrating a set of images, to be displayed as animated seres.
    
    Components implementing this interface maintain a variable number of image sets. Components displaying those images will choose the best-fitting image set depending on the available space, and possibly other restrictions.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XAnimatedImages <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XAnimatedImages.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XAnimatedImages'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XAnimatedImages'

    @abstractmethod
    def getImageSet(self, iIndex: int) -> typing.Tuple[str, ...]:
        """
        returns the URLs of the image set with the given index

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getImageSetCount(self) -> int:
        """
        returns the number of images sets maintained by the component.
        """
        ...
    @abstractmethod
    def insertImageSet(self, iIndex: int, iImageURLs: typing.Tuple[str, ...]) -> None:
        """
        sets the URLs of the image set with the given index

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def removeImageSet(self, iIndex: int) -> None:
        """
        removes the image set with the given index

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def replaceImageSet(self, iIndex: int, iImageURLs: typing.Tuple[str, ...]) -> None:
        """
        replaces the image set given by index with a new one

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractproperty
    def AutoRepeat(self) -> bool:
        """
        specifies whether the animation should start over with the first image of the image series when the last image has been played.
        
        The default value for this attribute is TRUE.
        """
        ...

    @abstractproperty
    def ScaleMode(self) -> int:
        """
        controls the way the images are scaled up or down, when the available space is larger or smaller than what is needed for them.
        
        Allowed values are those from the ImageScaleMode constants group.
        """
        ...

    @abstractproperty
    def StepTime(self) -> int:
        """
        specifies the time in milliseconds between two animation steps.
        
        This is the minimum time, the actual value might be longer due to system load. The default value will be 100 ms.
        """
        ...


__all__ = ['XAnimatedImages']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_presentation import XPresentation as XPresentation_30890f78

class Presentation(XPropertySet_bc180bfa, XPresentation_30890f78):
    """
    Service Class

    This service is a presentation that is available from a PresentationDocument via the XPresentationSupplier interface.

    See Also:
        `API Presentation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.Presentation'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AllowAnimations(self) -> bool:
        """
        enables/disables the shape animations.
        """
        ...

    @abstractproperty
    def CustomShow(self) -> str:
        """
        If this string is not empty, it contains the name of a customized show that is used for the presentation.
        """
        ...

    @abstractproperty
    def FirstPage(self) -> str:
        """
        If this string is not empty, it contains the name of the page where the presentation is started.
        """
        ...

    @abstractproperty
    def IsAlwaysOnTop(self) -> bool:
        """
        If this property is set to TRUE, the window of the presentation is always on top of all other windows.
        """
        ...

    @abstractproperty
    def IsAutomatic(self) -> bool:
        """
        If this property is TRUE, all pages are changed automatically.
        
        This overrides the properties of the pages.
        """
        ...

    @abstractproperty
    def IsEndless(self) -> bool:
        """
        If this property is set to TRUE, the presentation is repeated endlessly.
        """
        ...

    @abstractproperty
    def IsFullScreen(self) -> bool:
        """
        If this property is set to TRUE, the presentation runs in full-screen mode.
        """
        ...

    @abstractproperty
    def IsLivePresentation(self) -> bool:
        """
        With this property, you can set the presentation to live mode.
        
        Implementations that have no live mode capability may ignore this property and always return false.
        """
        ...

    @abstractproperty
    def IsMouseVisible(self) -> bool:
        """
        If this property is TRUE, the mouse is visible during the presentation.
        """
        ...

    @abstractproperty
    def Pause(self) -> int:
        """
        is the duration of the black screen after the presentation has finished.
        
        If this is set to 0, no black screen is shown.
        """
        ...

    @abstractproperty
    def StartWithNavigator(self) -> bool:
        """
        If this is set to TRUE, the Navigator is opened at the start of the presentation.
        """
        ...

    @abstractproperty
    def UsePen(self) -> bool:
        """
        If this is TRUE, a pen is shown during presentation.
        
        You can draw on the presentation with this pen.
        """
        ...


__all__ = ['Presentation']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_control import XControl as XControl_7a9c098d

class XControlContainer(XInterface_8f010a43):
    """
    Provides access to the controls within an UnoControlContainer.

    See Also:
        `API XControlContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XControlContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XControlContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XControlContainer'

    @abstractmethod
    def addControl(self, Name: str, Control: XControl_7a9c098d) -> None:
        """
        adds the given control with the specified name to the container.
        """
        ...
    @abstractmethod
    def getControl(self, aName: str) -> XControl_7a9c098d:
        """
        returns the control with the specified name.
        """
        ...
    @abstractmethod
    def getControls(self) -> typing.Tuple[XControl_7a9c098d, ...]:
        """
        returns all controls.
        """
        ...
    @abstractmethod
    def removeControl(self, Control: XControl_7a9c098d) -> None:
        """
        removes the given control from the container.
        """
        ...
    @abstractmethod
    def setStatusText(self, StatusText: str) -> None:
        """
        sets the status text in the status bar of the container.
        """
        ...

__all__ = ['XControlContainer']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from .x_classified_object import XClassifiedObject as XClassifiedObject_fa3b0dab
from .x_transacted_object import XTransactedObject as XTransactedObject_fb510dbd
from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XOLESimpleStorage(XNameContainer_cb90e47, XClassifiedObject_fa3b0dab, XTransactedObject_fb510dbd, XComponent_98dc0ab5):
    """
    This interface allows to access and change contents of OLE storages.
    
    This is a simple container allowing the access to OLE storages. The subcomponents are either OLE storages themselves or streams.

    See Also:
        `API XOLESimpleStorage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XOLESimpleStorage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XOLESimpleStorage'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XOLESimpleStorage'


__all__ = ['XOLESimpleStorage']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation
from __future__ import annotations
import typing
from abc import abstractproperty
from ..document.link_target import LinkTarget as LinkTarget_ca220c5c
from ..drawing.draw_page import DrawPage as DrawPage_a56e0aff
if typing.TYPE_CHECKING:
    from com.sun.star.presentation.FadeEffect import FadeEffectProto  # type: ignore
    from com.sun.star.presentation.AnimationSpeed import AnimationSpeedProto  # type: ignore

class DrawPage(LinkTarget_ca220c5c, DrawPage_a56e0aff):
    """
    Service Class

    This is the service provided by a com.sun.star.drawing.DrawPage inside a PresentationDocument.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API DrawPage <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1DrawPage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.DrawPage'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Change(self) -> int:
        """
        specifies how the page change is triggered.
        
        If this is 0, the user must click to start each object animation and to change the page. If set to 1, the page is automatically switched. If it is set to 2, all object effects run automatically, but the user has to click on the page to change it.
        """
        ...

    @abstractproperty
    def DateTimeFormat(self) -> int:
        """
        defines the format that is used to format a date and time text field on this page.
        
        This is only used if IsDateTimeFixed is FALSE.
        """
        ...

    @abstractproperty
    def DateTimeText(self) -> str:
        """
        defines the text that is displayed in a date and time textfield rendered on this page.
        
        This value is only used if IsDateTimeFixed is TRUE.
        """
        ...

    @abstractproperty
    def Duration(self) -> int:
        """
        If the property com.sun.star.drawing.DrawPage.Change is set to 1, this is the time in seconds this page is shown before switching to the next page.
        """
        ...

    @abstractproperty
    def Effect(self) -> FadeEffectProto:
        """
        This is the effect that is used to fade in this page.
        """
        ...

    @abstractproperty
    def FooterText(self) -> str:
        """
        defines the text that is displayed in a footer textfield rendered on this page.
        """
        ...

    @abstractproperty
    def HeaderText(self) -> str:
        """
        defines the text that is displayed in a header textfield rendered on this page.
        """
        ...

    @abstractproperty
    def HighResDuration(self) -> float:
        """
        If the property com.sun.star.drawing.DrawPage.Change is set to 1, this is the time in seconds this page is shown before switching to the next page, also permitting sub-second precision here.
        """
        ...

    @abstractproperty
    def IsDateTimeFixed(self) -> bool:
        """
        defines if a date and time text field shows a fixed string value or the current date on this page.
        """
        ...

    @abstractproperty
    def IsDateTimeVisible(self) -> bool:
        """
        defines if a date and time presentation shape from the master page is visible on this page.
        """
        ...

    @abstractproperty
    def IsFooterVisible(self) -> bool:
        """
        defines if a footer presentation shape from the master page is visible on this page.
        """
        ...

    @abstractproperty
    def IsHeaderVisible(self) -> bool:
        """
        defines if a header presentation shape from the master page is visible on this page.
        """
        ...

    @abstractproperty
    def IsPageNumberVisible(self) -> bool:
        """
        defines if a page number presentation shape from the master page is visible on this page.
        """
        ...

    @abstractproperty
    def Layout(self) -> int:
        """
        If this property is not ZERO, this number specifies a presentation layout for this page.
        """
        ...

    @abstractproperty
    def Speed(self) -> AnimationSpeedProto:
        """
        Defines the speed of the fade-in effect of this page.
        """
        ...

    @abstractproperty
    def TransitionDuration(self) -> float:
        """
        Specifies slide transition time in seconds.
        
        **since**
        
            LibreOffice 6.1
        """
        ...


__all__ = ['DrawPage']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
from abc import abstractmethod
from .x_input_sequence_checker import XInputSequenceChecker as XInputSequenceChecker_1eb00e9e

class XExtendedInputSequenceChecker(XInputSequenceChecker_1eb00e9e):
    """
    This interface perform input sequence correction for the languages like Thai and Hindi.
    
    It is derived from com.sun.star.i18n.XInputSequenceChecker and provides additional functionality to correct input sequence.
    
    **since**
    
        OOo 2.0.1

    See Also:
        `API XExtendedInputSequenceChecker <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedInputSequenceChecker.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XExtendedInputSequenceChecker'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XExtendedInputSequenceChecker'

    @abstractmethod
    def correctInputSequence(self, aText: object, nPos: int, cInputChar: str, nInputCheckMode: int) -> int:
        """
        """
        ...

__all__ = ['XExtendedInputSequenceChecker']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4

class XClob(XInterface_8f010a43):
    """
    is the mapping for the SQL CLOB type.
    
    A SQL CLOB is a built-in type that stores a Character Large Object as a column value in a row of a database table. The driver implements a Clob object using a SQL locator(CLOB) , which means that a Clob object contains a logical pointer to the SQL CLOB data rather than the data itself. A Clob object is valid for the duration of the transaction in which it was created.
    
    The Clob interface provides methods for getting the length of a SQL CLOB (Character Large Object) value, for materializing a CLOB value on the client, and for searching for a substring or CLOB object within a CLOB value.
    
    Methods in the interfaces com.sun.star.sdbc.XResultSet , and com.sun.star.sdbc.XPreparedStatement , such as getClob and setClob allow a programmer to access the SQL CLOB.

    See Also:
        `API XClob <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XClob'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XClob'

    @abstractmethod
    def getCharacterStream(self) -> XInputStream_98d40ab4:
        """
        gets the Clob contents as a stream.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getSubString(self, pos: int, length: int) -> str:
        """
        returns a copy of the specified substring in the Clob value designated by this Clob object.
        
        The substring begins at position pos and has up to length consecutive characters.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def length(self) -> int:
        """
        returns the number of characters in the CLOB value designated by this Clob object.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def position(self, searchstr: str, start: int) -> int:
        """
        determines the character position at which the specified substring searchstr appears in the Clob.
        
        The search begins at position start.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def positionOfClob(self, pattern: XClob, start: int) -> int:
        """
        determines the position at which the specified Clob object pattern appears in this Clob object.
        
        The search begins at position start.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XClob']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.scanner
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.x_bitmap import XBitmap as XBitmap_70cd0909
    from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
    from .scanner_context import ScannerContext as ScannerContext_f0c60da1
    from com.sun.star.scanner.ScanError import ScanErrorProto  # type: ignore

class XScannerManager(XInterface_8f010a43):
    """

    See Also:
        `API XScannerManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1scanner_1_1XScannerManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.scanner'
    __ooo_full_ns__: str = 'com.sun.star.scanner.XScannerManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.scanner.XScannerManager'

    @abstractmethod
    def configureScanner(self, scannerContext: object) -> bool:
        """
        produce some kind of User Interface to let the user have a preview, configure the scan area, etc., it returns FALSE if user cancelled this process

        Raises:
            com.sun.star.scanner.ScannerException: ``ScannerException``
        """
        ...
    @abstractmethod
    def getAvailableScanners(self) -> typing.Tuple[ScannerContext_f0c60da1, ...]:
        """
        returns all available scanner devices
        """
        ...
    @abstractmethod
    def getBitmap(self, scannerContext: ScannerContext_f0c60da1) -> XBitmap_70cd0909:
        """
        get the image after completion of scan

        Raises:
            com.sun.star.scanner.ScannerException: ``ScannerException``
        """
        ...
    @abstractmethod
    def getError(self, scannerContext: ScannerContext_f0c60da1) -> ScanErrorProto:
        """
        get the state of scanning after completion of scan

        Raises:
            com.sun.star.scanner.ScannerException: ``ScannerException``
        """
        ...
    @abstractmethod
    def startScan(self, scannerContext: ScannerContext_f0c60da1, listener: XEventListener_c7230c4a) -> None:
        """
        start the scanning process listener will be called when scan is complete the EventObject of the disposing call will contain the ScannerManager if the scan was successful, an empty interface otherwise

        Raises:
            com.sun.star.scanner.ScannerException: ``ScannerException``
        """
        ...

__all__ = ['XScannerManager']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.inspection
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_object_inspector_ui import XObjectInspectorUI as XObjectInspectorUI_5ccd1048

class DefaultHelpProvider(XInterface_8f010a43):
    """
    Service Class

    implements a component which can default-fill the help section of an ObjectInspector.
    
    The component registers a XPropertyControlObserver at an XObjectInspectoryUI interface. Whenever it then is notified of a XPropertyControl getting the focus, it will try to deduce the extended help text of this control's window, and set this help text at the object inspector's help section.

    See Also:
        `API DefaultHelpProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1inspection_1_1DefaultHelpProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.DefaultHelpProvider'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, InspectorUI: XObjectInspectorUI_5ccd1048) -> None:
        """
        creates a help provider instance

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['DefaultHelpProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XColumnLocate(XInterface_8f010a43):
    """
    provides the possibility to find columns by their name.
    
    When several columns have the same name, then the value of the first matching column will be returned. The column name option is designed to be used when column names are used in the SQL query. For columns that are NOT explicitly named in the query, it is best to use column numbers. If column names are used, there is no way for the programmer to guarantee that they actually refer to the intended columns.

    See Also:
        `API XColumnLocate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XColumnLocate.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XColumnLocate'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XColumnLocate'

    @abstractmethod
    def findColumn(self, columnName: str) -> int:
        """
        maps the given ResultSet column name to its ResultSet column index.
        
        The specification before LibreOffice 4.2 left unspecified what should happen for an invalid column name. As a result some drivers written against the older specification may return a special invalid value, such as a negative number, zero, or a number greater than the number of columns.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XColumnLocate']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.io
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class FilePermission(object):
    """
    Struct Class

    This permission represents access to a file or directory.
    
    A FilePermission consists of a file url and a set of actions valid for that url.
    
    The path of the file url that ends in \"/*\" indicates all the files and directories contained in that directory. A path that ends with \"/-\" indicates (recursively) all files and subdirectories contained in that directory. A file url string consisting of the special token \"<<ALL FILES>>\" matches any file. Note: A file url string consisting of a single \"*\" indicates all the files in the current directory, while a string consisting of a single \"-\" indicates all the files in the current directory and (recursively) all files and subdirectories contained in the current directory. The actions to be granted is a list of one or more comma-separated keywords. The possible keywords are \"read\", \"write\", \"execute\", and \"delete\". Their meaning is defined as follows:
    
    The actions string is processed case-insensitive.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API FilePermission <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1io_1_1FilePermission.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.FilePermission'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.io.FilePermission'
    """Literal Constant ``com.sun.star.io.FilePermission``"""

    def __init__(self, URL: typing.Optional[str] = '', Actions: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            URL (str, optional): URL value.
            Actions (str, optional): Actions value.
        """
        super().__init__()

        if isinstance(URL, FilePermission):
            oth: FilePermission = URL
            self.URL = oth.URL
            self.Actions = oth.Actions
            return

        kargs = {
            "URL": URL,
            "Actions": Actions,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._url = kwargs["URL"]
        self._actions = kwargs["Actions"]


    @property
    def URL(self) -> str:
        """
        target file url
        """
        return self._url

    @URL.setter
    def URL(self, value: str) -> None:
        self._url = value

    @property
    def Actions(self) -> str:
        """
        comma separated actions list
        """
        return self._actions

    @Actions.setter
    def Actions(self, value: str) -> None:
        self._actions = value


__all__ = ['FilePermission']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XOutParameters(XInterface_8f010a43):
    """
    is used to register Out-Parameters for stored procedures.
    
    SDBC provides a stored procedure SQL escape that allows stored procedures to be called in a standard way for all RDBMSs. This escape syntax has one form that includes a result parameter and one that does not. If used, the result parameter must be registered as an OUT parameter. The other parameters can be used for input, output, or both. Parameters are referred to sequentially, by number. The first parameter is 1.

    See Also:
        `API XOutParameters <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XOutParameters.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XOutParameters'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XOutParameters'

    @abstractmethod
    def registerNumericOutParameter(self, parameterIndex: int, sqlType: int, scale: int) -> None:
        """
        registers the OUT parameter in ordinal position parameterIndex to the SDBC type sqlType.
        
        All OUT parameters must be registered before a stored procedure is executed.
        
        The SDBC type specified by sqlType for an OUT parameter determines the type that must be used in the get method to read the value of that parameter. This version of com.sun.star.sdbc.XOutParameters.registerOutParameter() should be used when the parameter is of SDBC type com.sun.star.sdbc.DataType.NUMERIC or com.sun.star.sdbc.DataType.DECIMAL.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def registerOutParameter(self, parameterIndex: int, sqlType: int, typeName: str) -> None:
        """
        registers the designated output parameter.
        
        This version of the method com.sun.star.sdbc.XOutParameters.registerOutParameter() should be used for a user-named or REF output parameter. Examples of user-named types include: STRUCT, DISTINCT, OBJECT, and named array types.
        
        Before executing a stored procedure call, you must explicitly call com.sun.star.sdbc.XOutParameters.registerOutParameter() to register the type from com.sun.star.sdbc.DataType for each OUT parameter. For a user-named parameter the fully-qualified SQL type name of the parameter should also be given, while a REF parameter requires that the fully-qualified type name of the referenced type be given. An SDBC driver that does not need the type code and type name information may ignore it. To be portable, however, applications should always provide these values for user-named and REF parameters.
        
        Although it is intended for user-named and REF parameters, this method may be used to register a parameter of any SDBC type. If the parameter does not have a user-named or REF type, the typeName parameter is ignored.
        
        Note: When reading the value of an out parameter, you must use the getXXX method whose type XXX corresponds to the parameter's registered SQL type.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XOutParameters']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.lang
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_connection_point_container import XConnectionPointContainer as XConnectionPointContainer_688110bf

class XConnectionPoint(XInterface_8f010a43):
    """
    supports connection points for connectable objects.
    
    Connectable objects support the following features:
    
    To create a connectable object, you need to implement objects that provide two related interfaces:
    
    The XConnectionPointContainer interface is implemented on the connectable object to indicate the existence of the outgoing interfaces. It provides a sequence of sub-objects. It also provides access to all the connection point sub-objects, each of which implements the XConnectionPoint interface. The XConnectionPoint interface provides a sequence of sub-objects.
    
    Each connection point is a separate sub-object to avoid circular reference counting problems. A connection point controls how many connections (one or more) it will allow in its implementation of XConnectionPoint.advise().
    
    A client can use the XConnectionPointContainer interface:

    See Also:
        `API XConnectionPoint <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1lang_1_1XConnectionPoint.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.XConnectionPoint'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.lang.XConnectionPoint'

    @abstractmethod
    def advise(self, xListener: XInterface_8f010a43) -> None:
        """
        creates a connection between a connection point and a client's sink, where the sink implements the outgoing interface supported by this connection point.
        
        A few add...Listener methods need additional parameters to add listeners or throw exceptions. One of these methods is com.sun.star.beans.XPropertySet.addPropertyChangeListener(). We ignore the problem in this interface. A solution must be provided in an additional XConnectionPoint interface.

        Raises:
            com.sun.star.lang.ListenerExistException: ``ListenerExistException``
            com.sun.star.lang.InvalidListenerException: ``InvalidListenerException``
        """
        ...
    @abstractmethod
    def getConnectionPointContainer(self) -> XConnectionPointContainer_688110bf:
        """
        """
        ...
    @abstractmethod
    def getConnectionType(self) -> object:
        """
        Using the XConnectionPointContainer.getConnectionPoints() method, a client can obtain an XConnectionPoint interface. Using that interface and this method, the client can determine the type of each connection point enumerated. The type returned from this method must enable the caller to access this same connection point through XConnectionPointContainer.findConnectionPoint().
        """
        ...
    @abstractmethod
    def getConnections(self) -> typing.Tuple[XInterface_8f010a43, ...]:
        """
        """
        ...
    @abstractmethod
    def unadvise(self, xListener: XInterface_8f010a43) -> None:
        """
        terminates a notification previously set up with advise.
        
        A few remove...Listener methods need additional parameters to add listeners or throw exceptions. One of these methods is com.sun.star.beans.XPropertySet.removePropertyChangeListener(). We ignore the problem in this interface. A solution must be provided in an additional XConnectionPoint interface.
        """
        ...

__all__ = ['XConnectionPoint']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
from abc import abstractmethod, ABC

class XAsyncOutputMonitor(ABC):
    """
    An optional companion interface to com.sun.star.io.XOutputStream that supports scenarios where com.sun.star.io.XOutputStream.writeBytes() operates asynchronously and does not necessarily report any errors.
    
    A typical scenario where this interface is useful is when an com.sun.star.io.XOutputStream is used to write to a file via NFS. Normally, any calls to com.sun.star.io.XOutputStream.writeBytes() will execute asynchronously then, in that any potential errors might only be reported by later calls to com.sun.star.io.XOutputStream.writeBytes() or com.sun.star.io.XOutputStream.closeOutput(). If such an output stream shall not be closed immediately after one or more calls to com.sun.star.io.XOutputStream.writeBytes(), but the client wants to know as soon as possible whether writing was successful, then com.sun.star.io.XAsyncOutputMonitor.waitForCompletion() should be called after the series of calls to com.sun.star.io.XOutputStream.writeBytes().
    
    **since**
    
        OOo 2.0

    See Also:
        `API XAsyncOutputMonitor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XAsyncOutputMonitor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XAsyncOutputMonitor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XAsyncOutputMonitor'

    @abstractmethod
    def waitForCompletion(self) -> None:
        """
        waits for the completion of any previous calls to com.sun.star.io.XOutputStream.writeBytes(), and reports potentially pending errors.
        
        Calling this method is potentially expensive (even if the associated com.sun.star.io.XOutputStream represents a local file not accessed via NFS, for example). This method has a similar description to com.sun.star.io.XOutputStream.flush(). However, where the semantics of flush are rather vague, waitForCompletion has very specific semantics—it just blocks long enough so that any errors encountered during previous calls to com.sun.star.io.XOutputStream.writeBytes() can reliably be reported. It specifically does not guarantee that any data have safely been stored on a stable physical medium, like a hard disk (and it is completely unspecified whether flush should give this guarantee).

        Raises:
            IOException: ``IOException``
        """
        ...

__all__ = ['XAsyncOutputMonitor']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractproperty, ABC

class LineNumberingProperties(ABC):
    """
    Service Class

    provides access to the settings of the line numbering.
    
    **since**
    
        OOo 2.0

    See Also:
        `API LineNumberingProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1LineNumberingProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.LineNumberingProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CharStyleName(self) -> str:
        """
        The name of the character style that is used for the line number.
        """
        ...

    @abstractproperty
    def CountEmptyLines(self) -> bool:
        """
        If TRUE, empty lines are counted.
        """
        ...

    @abstractproperty
    def CountLinesInFrames(self) -> bool:
        """
        If TRUE, lines in frames are included in counting.
        """
        ...

    @abstractproperty
    def Distance(self) -> int:
        """
        specifies the distance between the line number and the start or end of the text area.
        """
        ...

    @abstractproperty
    def Interval(self) -> int:
        """
        Line numbers are shown on every Intervalth line.
        """
        ...

    @abstractproperty
    def IsOn(self) -> bool:
        """
        If TRUE, line numbering is used.
        """
        ...

    @abstractproperty
    def NumberPosition(self) -> int:
        """
        specifies the position of the line number (constant LineNumberPositions left/right/inside/outside).
        """
        ...

    @abstractproperty
    def NumberingType(self) -> int:
        """
        specifies the type of the numbering.
        """
        ...

    @abstractproperty
    def RestartAtEachPage(self) -> bool:
        """
        specifies if the line numbering should start from the beginning at each page.
        
        If set to FALSE the line numbering will be continuous.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def SeparatorInterval(self) -> int:
        """
        The line separator is shown every SeparatorIntervalth line.
        """
        ...

    @abstractproperty
    def SeparatorText(self) -> str:
        """
        specifies the string that is used for the line separator.
        """
        ...


__all__ = ['LineNumberingProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from .x_content_provider import XContentProvider as XContentProvider_d4150cc0
from .x_content_provider_supplier import XContentProviderSupplier as XContentProviderSupplier_48e61014
from .x_parameterized_content_provider import XParameterizedContentProvider as XParameterizedContentProvider_9dc6120d

class ContentProviderProxy(XContentProvider_d4150cc0, XContentProviderSupplier_48e61014, XParameterizedContentProvider_9dc6120d):
    """
    Service Class

    is a proxy for a content provider.
    
    Implementing a content provider proxy can be useful if the creation of the real content provider object shall be deferred for some reason (i.e. performance) until the first method gets called on it. Instead of instantiating and registering the real provider at the UCB, a proxy for the real provider can be created and registered at the UCB.

    See Also:
        `API ContentProviderProxy <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1ContentProviderProxy.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.ContentProviderProxy'
    __ooo_type_name__: str = 'service'


__all__ = ['ContentProviderProxy']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FrameSearchFlag(metaclass=UnoConstMeta, type_name="com.sun.star.frame.FrameSearchFlag", name_space="com.sun.star.frame"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.frame.FrameSearchFlag``"""
        pass

    class FrameSearchFlagEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.frame.FrameSearchFlag", name_space="com.sun.star.frame"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.frame.FrameSearchFlag`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.frame import FrameSearchFlag as FrameSearchFlag
    else:
        # keep document generators happy
        from ...lo.frame.frame_search_flag import FrameSearchFlag as FrameSearchFlag

    class FrameSearchFlagEnum(IntEnum):
        """
        Enum of Const Class FrameSearchFlag

        these types describe the algorithm to be used to search a frame
        
        Such flags will be used on methods XFrame.findFrame(), XDispatchProvider.queryDispatch() or XComponentLoader.loadComponentFromURL() if no special target frame name (e.g. \"_blank\", \"_self\") is used.
        """
        AUTO = FrameSearchFlag.AUTO
        """
        no longer supported
        
        Using of this flag will do nothing. Use right combination of other flags instead of this one.
        """
        PARENT = FrameSearchFlag.PARENT
        """
        allows search on the parent frames
        """
        SELF = FrameSearchFlag.SELF
        """
        includes the start frame himself
        """
        CHILDREN = FrameSearchFlag.CHILDREN
        """
        includes all child frames of the start frame
        
        Note: That means all direct children and of course her children too. Search doesn't stop at the next level inside the tree!
        """
        CREATE = FrameSearchFlag.CREATE
        """
        frame will be created if not found
        """
        SIBLINGS = FrameSearchFlag.SIBLINGS
        """
        includes the direct siblings of the start frame
        
        Normally it's interpreted as search on the direct children of the parent only. But in combination with e.g. the CHILDREN flag it can include all children of it too.
        """
        TASKS = FrameSearchFlag.TASKS
        """
        allow the search outside the current sub task tree of the whole possible frame tree
        
        If this flag isn't present, any search from bottom to top has to stop, if a top frame will be reached. It doesn't influence a search from top to bottom. But it can be used at the root of the frame tree to search on direct children of it only. Because the direct children of the root node are the root's of the task sub trees, which are top frames too. Instead of using the CHILDREN flag there, it's possible so to suppress a deeper search so.
        """
        ALL = FrameSearchFlag.ALL
        """
        includes all frames except frames in other tasks sub trees but doesn't create any new frame
        """
        GLOBAL = FrameSearchFlag.GLOBAL
        """
        searches in the whole hierarchy of frames but doesn't create any new frame
        """

__all__ = ['FrameSearchFlag', 'FrameSearchFlagEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .boundary import Boundary as Boundary_7fe2098c


class TextConversionResult(object):
    """
    Struct Class

    Text conversion result to be used with XTextConversion.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TextConversionResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1TextConversionResult.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.TextConversionResult'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.TextConversionResult'
    """Literal Constant ``com.sun.star.i18n.TextConversionResult``"""

    def __init__(self, Candidates: typing.Optional[typing.Tuple[str, ...]] = (), Boundary: typing.Optional[Boundary_7fe2098c] = UNO_NONE) -> None:
        """
        Constructor

        Arguments:
            Candidates (typing.Tuple[str, ...], optional): Candidates value.
            Boundary (Boundary, optional): Boundary value.
        """
        super().__init__()

        if isinstance(Candidates, TextConversionResult):
            oth: TextConversionResult = Candidates
            self.Candidates = oth.Candidates
            self.Boundary = oth.Boundary
            return

        kargs = {
            "Candidates": Candidates,
            "Boundary": Boundary,
        }
        if kargs["Boundary"] is UNO_NONE:
            kargs["Boundary"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._candidates = kwargs["Candidates"]
        self._boundary = kwargs["Boundary"]


    @property
    def Candidates(self) -> typing.Tuple[str, ...]:
        """
        A list of replacement candidates for the first convertible word found in the given text.
        """
        return self._candidates

    @Candidates.setter
    def Candidates(self, value: typing.Tuple[str, ...]) -> None:
        self._candidates = value

    @property
    def Boundary(self) -> Boundary_7fe2098c:
        """
        The boundary of the first convertible word in the given text.
        
        If there is no convertible word found in the text, startPos and endPos for Boundary equal 0.
        """
        return self._boundary

    @Boundary.setter
    def Boundary(self, value: Boundary_7fe2098c) -> None:
        self._boundary = value


__all__ = ['TextConversionResult']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
from abc import abstractmethod
from .x_output_stream import XOutputStream as XOutputStream_a4e00b35

class XTextOutputStream(XOutputStream_a4e00b35):
    """
    Interface to write strings to a stream using a special character encoding.
    
    This interfaces allows to write strings to a stream. The character encoding to be used can be set by setEncoding(). Default encoding is \"utf8\".

    See Also:
        `API XTextOutputStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XTextOutputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XTextOutputStream'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XTextOutputStream'

    @abstractmethod
    def setEncoding(self, Encoding: str) -> None:
        """
        sets character encoding.
        """
        ...
    @abstractmethod
    def writeString(self, aString: str) -> None:
        """
        writes a string to the stream using the encoding defined by setEncoding().
        
        Line breaks or delimiters that may be necessary to support XTextInputStream.readLine() and XTextInputStream.readString() have to be added manually to the parameter string.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XTextOutputStream']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_slide_show_view import XSlideShowView as XSlideShowView_3eb40fa9
    from .x_transition import XTransition as XTransition_123a0ea7
    from ..rendering.x_bitmap import XBitmap as XBitmap_b1b70b7b

class XTransitionFactory(XInterface_8f010a43):
    """
    TransitionFactory interface to request optional custom Transition instances for slide show transitions.
    
    This interface provides the necessary methods to query and create optional transition effects for a SlideShow
    
    **since**
    
        OOo 2.4

    See Also:
        `API XTransitionFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1presentation_1_1XTransitionFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.XTransitionFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.presentation.XTransitionFactory'

    @abstractmethod
    def createTransition(self, transitionType: int, transitionSubType: int, transitionFadeColor: int, view: XSlideShowView_3eb40fa9, leavingBitmap: XBitmap_b1b70b7b, enteringBitmap: XBitmap_b1b70b7b) -> XTransition_123a0ea7:
        """
        Actually create a transition for the given transition id.
        """
        ...
    @abstractmethod
    def hasTransition(self, transitionType: int, transitionSubType: int) -> bool:
        """
        Checks whether this instance provides an implementation for given transition id.
        """
        ...

__all__ = ['XTransitionFactory']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.inspection
from __future__ import annotations
from ...inspection.x_property_handler import XPropertyHandler as XPropertyHandler_3e950fbf

class XSDValidationPropertyHandler(XPropertyHandler_3e950fbf):
    """
    Service Class

    implements a property handler for use with a com.sun.star.inspection.ObjectInspector which provides properties related to binding form control models to XForm bindings and validating the form control content.
    
    By using an XMLFormsPropertyHandler, a com.sun.star.inspection.ObjectInspector can be used to bind form components to com.sun.star.xforms.Binding instances. Since those instances also support validating form control content (by supporting an com.sun.star.form.validation.XValidator interface), it seems reasonable to edit those validate-related properties (like the XSD data type to validate against) in the com.sun.star.inspection.ObjectInspector, too. This is what an XSDValidationPropertyHandler is good for.
    
    The handler expects a value named \"ContextDocument\" in the context in which it is created. That is, the com.sun.star.uno.XComponentContext used for creating the CellBindingPropertyHandler is examined for a value with this name. If the object in this value denotes a XML form document (indicated by supporting the com.sun.star.xforms.XFormsSupplier interface), this document is used to do XML binding related work.

    See Also:
        `API XSDValidationPropertyHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1XSDValidationPropertyHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.inspection'
    __ooo_full_ns__: str = 'com.sun.star.form.inspection.XSDValidationPropertyHandler'
    __ooo_type_name__: str = 'service'


__all__ = ['XSDValidationPropertyHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_connection import XConnection as XConnection_a36a0b0c
    from .x_result_set import XResultSet as XResultSet_98e30aa7

class XDatabaseMetaData(XInterface_8f010a43):
    """
    provides comprehensive information about the database as a whole.
    
    Many of the methods here return lists of information in the form of com.sun.star.sdbc.XResultSet objects. You can use the normal com.sun.star.sdbc.XRow (or com.sun.star.sdb.XColumn) methods such as com.sun.star.sdbc.XRow.getString() and com.sun.star.sdbc.XRow.getInt() to retrieve the data from these XResultSets. If a given form of metadata is not available, these methods should throw a com.sun.star.sdbc.SQLException. After calling one of the getXXX() methods, one can check whether that value is NULL with the method com.sun.star.sdbc.XRow.wasNull(). In the text only \"(may be `NULL`)\" is mentioned for this case.
    
    Some of these methods take arguments that are String patterns. These arguments all have names such as fooPattern. Within a pattern String, \"%\" means match any substring of 0 or more characters, and \"_\" means match any one character. Only metadata entries matching the search pattern are returned. If a search pattern argument is set to VOID, that argument's criteria will be dropped from the search.
    
    A com.sun.star.sdbc.SQLException will be thrown if a driver does not support a metadata method. In the case of methods that return an XResultSet, either an XResultSet (which may be empty) is returned or a SQLException is thrown.

    See Also:
        `API XDatabaseMetaData <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XDatabaseMetaData'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XDatabaseMetaData'

    @abstractmethod
    def allProceduresAreCallable(self) -> bool:
        """
        Can all the procedures returned by getProcedures be called by the current user?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def allTablesAreSelectable(self) -> bool:
        """
        Can all the tables returned by getTable be SELECTed by the current user?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def dataDefinitionCausesTransactionCommit(self) -> bool:
        """
        does a data definition statement within a transaction force the transaction to commit?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def dataDefinitionIgnoredInTransactions(self) -> bool:
        """
        is a data definition statement within a transaction ignored?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def deletesAreDetected(self, setType: int) -> bool:
        """
        indicates whether or not a visible row delete can be detected by calling com.sun.star.sdbc.XResultSet.rowDeleted().
        
        If deletesAreDetected() returns FALSE, then deleted rows are removed from the result set.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def doesMaxRowSizeIncludeBlobs(self) -> bool:
        """
        Did getMaxRowSize() include LONGVARCHAR and LONGVARBINARY blobs?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getBestRowIdentifier(self, catalog: object, schema: str, table: str, scope: int, nullable: bool) -> XResultSet_98e30aa7:
        """
        gets a description of a table's optimal set of columns that uniquely identifies a row.
        
        They are ordered by SCOPE.
        
        Each column description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getCatalogSeparator(self) -> str:
        """
        return the separator between catalog and table name

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getCatalogTerm(self) -> str:
        """
        return the database vendor's preferred term for \"catalog\"

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getCatalogs(self) -> XResultSet_98e30aa7:
        """
        gets the catalog names available in this database.
        
        The results are ordered by catalog name.
        
        The catalog column is:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getColumnPrivileges(self, catalog: object, schema: str, table: str, columnNamePattern: str) -> XResultSet_98e30aa7:
        """
        gets a description of the access rights for a table's columns.
        
        Only privileges matching the column name criteria are returned. They are ordered by COLUMN_NAME and PRIVILEGE.
        
        Each privilege description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getColumns(self, catalog: object, schemaPattern: str, tableNamePattern: str, columnNamePattern: str) -> XResultSet_98e30aa7:
        """
        gets a description of table columns available in the specified catalog.
        
        Only column descriptions matching the catalog, schema, table and column name criteria are returned. They are ordered by TABLE_SCHEM, TABLE_NAME, and ORDINAL_POSITION.
        
        Each column description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getConnection(self) -> XConnection_a36a0b0c:
        """
        retrieves the connection that produced this metadata object.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getCrossReference(self, primaryCatalog: object, primarySchema: str, primaryTable: str, foreignCatalog: object, foreignSchema: str, foreignTable: str) -> XResultSet_98e30aa7:
        """
        gets a description of the foreign key columns in the foreign key table that reference the primary key columns of the primary key table (describe how one table imports another's key.) This should normally return a single foreign key/primary key pair (most tables only import a foreign key from a table once.).
        
        They are ordered by FKTABLE_CAT, FKTABLE_SCHEM, FKTABLE_NAME, and KEY_SEQ.
        
        Each foreign key column description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getDatabaseProductName(self) -> str:
        """
        returns the name of the database product.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getDatabaseProductVersion(self) -> str:
        """
        returns the version of the database product.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getDefaultTransactionIsolation(self) -> int:
        """
        return the database default transaction isolation level.
        
        The values are defined in com.sun.star.sdbc.TransactionIsolation.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getDriverMajorVersion(self) -> int:
        """
        returns the SDBC driver major version number.
        """
        ...
    @abstractmethod
    def getDriverMinorVersion(self) -> int:
        """
        returns the SDBC driver minor version number.
        """
        ...
    @abstractmethod
    def getDriverName(self) -> str:
        """
        returns the name of the SDBC driver.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getDriverVersion(self) -> str:
        """
        returns the version number of the SDBC driver.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getExportedKeys(self, catalog: object, schema: str, table: str) -> XResultSet_98e30aa7:
        """
        gets a description of the foreign key columns that reference a table's primary key columns (the foreign keys exported by a table).
        
        They are ordered by FKTABLE_CAT, FKTABLE_SCHEM, FKTABLE_NAME, and KEY_SEQ.
        
        Each foreign key column description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getExtraNameCharacters(self) -> str:
        """
        gets all the \"extra\" characters that can be used in unquoted identifier names (those beyond a-z, A-Z, 0-9 and _).

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getIdentifierQuoteString(self) -> str:
        """
        What's the string used to quote SQL identifiers? This returns a space \" \" if identifier quoting is not supported.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getImportedKeys(self, catalog: object, schema: str, table: str) -> XResultSet_98e30aa7:
        """
        gets a description of the primary key columns that are referenced by a table's foreign key columns (the primary keys imported by a table).
        
        They are ordered by PKTABLE_CAT, PKTABLE_SCHEM, PKTABLE_NAME, and KEY_SEQ.
        
        Each primary key column description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getIndexInfo(self, catalog: object, schema: str, table: str, unique: bool, approximate: bool) -> XResultSet_98e30aa7:
        """
        gets a description of a table's indices and statistics.
        
        They are ordered by NON_UNIQUE, TYPE, INDEX_NAME, and ORDINAL_POSITION.
        
        Each index column description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxBinaryLiteralLength(self) -> int:
        """
        return the maximal number of hex characters in an inline binary literal

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxCatalogNameLength(self) -> int:
        """
        return the maximum length of a catalog name

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxCharLiteralLength(self) -> int:
        """
        return the max length for a character literal

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxColumnNameLength(self) -> int:
        """
        return the limit on column name length

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxColumnsInGroupBy(self) -> int:
        """
        return the maximum number of columns in a \"GROUP BY\" clause

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxColumnsInIndex(self) -> int:
        """
        return the maximum number of columns allowed in an index

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxColumnsInOrderBy(self) -> int:
        """
        return the maximum number of columns in an \"ORDER BY\" clause

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxColumnsInSelect(self) -> int:
        """
        return the maximum number of columns in a \"SELECT\" list

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxColumnsInTable(self) -> int:
        """
        return the maximum number of columns in a table

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxConnections(self) -> int:
        """
        return the number of active connections at a time to this database.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxCursorNameLength(self) -> int:
        """
        return the maximum cursor name length

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxIndexLength(self) -> int:
        """
        return the maximum length of an index (in bytes)

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxProcedureNameLength(self) -> int:
        """
        return the maximum length of a procedure name

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxRowSize(self) -> int:
        """
        return the maximum length of a single row.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxSchemaNameLength(self) -> int:
        """
        return the maximum length allowed for a schema name

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxStatementLength(self) -> int:
        """
        return the maximum length of a SQL statement

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxStatements(self) -> int:
        """
        return the maximal number of open active statements at one time to this database

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxTableNameLength(self) -> int:
        """
        return the maximum length of a table name

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxTablesInSelect(self) -> int:
        """
        return the maximum number of tables in a SELECT statement

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getMaxUserNameLength(self) -> int:
        """
        return the maximum length of a user name

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getNumericFunctions(self) -> str:
        """
        gets a comma-separated list of math functions.
        
        These are the X/Open CLI math function names used in the SDBC function escape clause.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getPrimaryKeys(self, catalog: object, schema: str, table: str) -> XResultSet_98e30aa7:
        """
        gets a description of a table's primary key columns.
        
        They are ordered by COLUMN_NAME.
        
        Each primary key column description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getProcedureColumns(self, catalog: object, schemaPattern: str, procedureNamePattern: str, columnNamePattern: str) -> XResultSet_98e30aa7:
        """
        gets a description of a catalog's stored procedure parameters and result columns.
        
        Only descriptions matching the schema, procedure and parameter name criteria are returned. They are ordered by PROCEDURE_SCHEM and PROCEDURE_NAME. Within this, the return value, if any, is first. Next are the parameter descriptions in call order. The column descriptions follow in column number order.
        
        Each row in the XResultSet is a parameter description or column description with the following fields:
        
        Note: Some databases may not return the column descriptions for a procedure. Additional columns beyond REMARKS can be defined by the database.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getProcedureTerm(self) -> str:
        """
        return the database vendor's preferred term for \"procedure\"

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getProcedures(self, catalog: object, schemaPattern: str, procedureNamePattern: str) -> XResultSet_98e30aa7:
        """
        Gets a description of the stored procedures available in a catalog.
        
        Only procedure descriptions matching the schema and procedure name criteria are returned. They are ordered by PROCEDURE_SCHEM, and PROCEDURE_NAME.
        
        Each procedure description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getSQLKeywords(self) -> str:
        """
        gets a comma-separated list of all a database's SQL keywords that are NOT also SQL92 keywords.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getSchemaTerm(self) -> str:
        """
        return the database vendor's preferred term for \"schema\"

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getSchemas(self) -> XResultSet_98e30aa7:
        """
        Gets the schema names available in this database.
        
        The results are ordered by schema name.
        
        The schema column is:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getSearchStringEscape(self) -> str:
        """
        gets the string that can be used to escape wildcard characters.
        
        This is the string that can be used to escape \"_\" or \"%\" in the string pattern style catalog search parameters.
        
        The \"_\" character represents any single character.
        
        The \"%\" character represents any sequence of zero or more characters.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getStringFunctions(self) -> str:
        """
        gets a comma-separated list of string functions.
        
        These are the X/Open CLI string function names used in the SDBC function escape clause.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getSystemFunctions(self) -> str:
        """
        gets a comma-separated list of system functions.
        
        These are the X/Open CLI system function names used in the SDBC function escape clause.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getTablePrivileges(self, catalog: object, schemaPattern: str, tableNamePattern: str) -> XResultSet_98e30aa7:
        """
        gets a description of the access rights for each table available in a catalog.
        
        Note that a table privilege applies to one or more columns in the table. It would be wrong to assume that this privilege applies to all columns (this may be TRUE for some systems but is not TRUE for all.)
        
        Only privileges matching the schema and table name criteria are returned. They are ordered by TABLE_SCHEM, TABLE_NAME, and PRIVILEGE.
        
        Each privilege description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getTableTypes(self) -> XResultSet_98e30aa7:
        """
        gets the table types available in this database.
        
        The results are ordered by table type.
        
        The table type is:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getTables(self, catalog: object, schemaPattern: str, tableNamePattern: str, types: typing.Tuple[str, ...]) -> XResultSet_98e30aa7:
        """
        gets a description of tables available in a catalog.
        
        Only table descriptions matching the catalog, schema, table name, and type criteria are returned. They are ordered by TABLE_TYPE, TABLE_SCHEM, and TABLE_NAME.
        
        Each table description has the following columns:
        
        Note: Some databases may not return information for all tables.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getTimeDateFunctions(self) -> str:
        """
        gets a comma-separated list of time and date functions.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getTypeInfo(self) -> XResultSet_98e30aa7:
        """
        gets a description of all the standard SQL types supported by this database.
        
        They are ordered by DATA_TYPE and then by how closely the data type maps to the corresponding SDBC SQL type.
        
        Each type description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getUDTs(self, catalog: object, schemaPattern: str, typeNamePattern: str, types: uno.ByteSequence) -> XResultSet_98e30aa7:
        """
        Gets a description of the user-defined types defined in a particular schema.
        
        Schema-specific UDTs may have type OBJECT, STRUCT, or DISTINCT.
        
        Only types matching the catalog, schema, type name, and type criteria are returned. They are ordered by DATA_TYPE, TYPE_SCHEM, and TYPE_NAME. The type name parameter may be a fully-qualified name. In this case, the catalog and schemaPattern parameters are ignored.
        
        Each type description has the following columns:
        
        Note: If the driver does not support UDTs, an empty result set is returned.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getURL(self) -> str:
        """
        returns the URL for the database connection

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getUserName(self) -> str:
        """
        returns the user name from this database connection.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getVersionColumns(self, catalog: object, schema: str, table: str) -> XResultSet_98e30aa7:
        """
        gets a description of a table's columns that are automatically updated when any value in a row is updated.
        
        They are unordered.
        
        Each column description has the following columns:

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def insertsAreDetected(self, setType: int) -> bool:
        """
        indicates whether or not a visible row insert can be detected by calling com.sun.star.sdbc.XResultSet.rowInserted().
        
        ()

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isCatalogAtStart(self) -> bool:
        """
        Does a catalog appear at the start of a qualified table name? (Otherwise it appears at the end)

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isReadOnly(self) -> bool:
        """
        checks if the database in read-only mode.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def nullPlusNonNullIsNull(self) -> bool:
        """
        are concatenations between NULL and non-NULL values NULL?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def nullsAreSortedAtEnd(self) -> bool:
        """
        Are NULL values sorted at the end, regardless of sort order?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def nullsAreSortedAtStart(self) -> bool:
        """
        Are NULL values sorted at the start regardless of sort order?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def nullsAreSortedHigh(self) -> bool:
        """
        Are NULL values sorted high?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def nullsAreSortedLow(self) -> bool:
        """
        Are NULL values sorted low?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def othersDeletesAreVisible(self, setType: int) -> bool:
        """
        indicates whether deletes made by others are visible.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def othersInsertsAreVisible(self, setType: int) -> bool:
        """
        indicates whether inserts made by others are visible.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def othersUpdatesAreVisible(self, setType: int) -> bool:
        """
        indicates whether updates made by others are visible.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def ownDeletesAreVisible(self, setType: int) -> bool:
        """
        indicates whether a result set's own deletes are visible.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def ownInsertsAreVisible(self, setType: int) -> bool:
        """
        indicates whether a result set's own inserts are visible.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def ownUpdatesAreVisible(self, setType: int) -> bool:
        """
        indicates whether a result set's own updates are visible.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def storesLowerCaseIdentifiers(self) -> bool:
        """
        Does the database treat mixed case unquoted SQL identifiers as case insensitive and store them in lower case?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def storesLowerCaseQuotedIdentifiers(self) -> bool:
        """
        Does the database treat mixed case quoted SQL identifiers as case insensitive and store them in lower case?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def storesMixedCaseIdentifiers(self) -> bool:
        """
        Does the database treat mixed case unquoted SQL identifiers as case insensitive and store them in mixed case?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def storesMixedCaseQuotedIdentifiers(self) -> bool:
        """
        Does the database treat mixed case quoted SQL identifiers as case insensitive and store them in mixed case?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def storesUpperCaseIdentifiers(self) -> bool:
        """
        Does the database treat mixed case unquoted SQL identifiers as case insensitive and store them in upper case?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def storesUpperCaseQuotedIdentifiers(self) -> bool:
        """
        Does the database treat mixed case quoted SQL identifiers as case insensitive and store them in upper case?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsANSI92EntryLevelSQL(self) -> bool:
        """

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsANSI92FullSQL(self) -> bool:
        """

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsANSI92IntermediateSQL(self) -> bool:
        """

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsAlterTableWithAddColumn(self) -> bool:
        """
        support the Database \"ALTER TABLE\" with add column?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsAlterTableWithDropColumn(self) -> bool:
        """
        support the Database \"ALTER TABLE\" with drop column?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsBatchUpdates(self) -> bool:
        """
        indicates whether the driver supports batch updates.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsCatalogsInDataManipulation(self) -> bool:
        """
        Can a catalog name be used in a data manipulation statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsCatalogsInIndexDefinitions(self) -> bool:
        """
        Can a catalog name be used in an index definition statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsCatalogsInPrivilegeDefinitions(self) -> bool:
        """
        Can a catalog name be used in a privilege definition statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsCatalogsInProcedureCalls(self) -> bool:
        """
        Can a catalog name be used in a procedure call statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsCatalogsInTableDefinitions(self) -> bool:
        """
        Can a catalog name be used in a table definition statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsColumnAliasing(self) -> bool:
        """
        support the Database column aliasing?
        
        The SQL AS clause can be used to provide names for computed columns or to provide alias names for columns as required.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsConvert(self, fromType: int, toType: int) -> bool:
        """
        TRUE , if the Database supports the CONVERT between the given SQL types otherwise FALSE.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsCoreSQLGrammar(self) -> bool:
        """
        TRUE, if the database supports ODBC Core SQL grammar, otherwise FALSE.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsCorrelatedSubqueries(self) -> bool:
        """
        Are correlated subqueries supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsDataDefinitionAndDataManipulationTransactions(self) -> bool:
        """
        support the Database both data definition and data manipulation statements within a transaction?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsDataManipulationTransactionsOnly(self) -> bool:
        """
        are only data manipulation statements within a transaction supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsDifferentTableCorrelationNames(self) -> bool:
        """
        If table correlation names are supported, are they restricted to be different from the names of the tables?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsExpressionsInOrderBy(self) -> bool:
        """
        Are expressions in \"ORDER BY\" lists supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsExtendedSQLGrammar(self) -> bool:
        """

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsFullOuterJoins(self) -> bool:
        """

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsGroupBy(self) -> bool:
        """
        Is some form of \"GROUP BY\" clause supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsGroupByBeyondSelect(self) -> bool:
        """
        Can a \"GROUP BY\" clause add columns not in the SELECT provided it specifies all the columns in the SELECT?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsGroupByUnrelated(self) -> bool:
        """
        Can a \"GROUP BY\" clause use columns not in the SELECT?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsIntegrityEnhancementFacility(self) -> bool:
        """
        returns TRUE, if the Database supports SQL Integrity Enhancement Facility, otherwise FALSE.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsLikeEscapeClause(self) -> bool:
        """
        Is the escape character in \"LIKE\" clauses supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsLimitedOuterJoins(self) -> bool:
        """

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsMinimumSQLGrammar(self) -> bool:
        """
        TRUE, if the database supports ODBC Minimum SQL grammar, otherwise FALSE.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsMixedCaseIdentifiers(self) -> bool:
        """
        use the database \"mixed case unquoted SQL identifiers\" case sensitive.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsMixedCaseQuotedIdentifiers(self) -> bool:
        """
        Does the database treat mixed case quoted SQL identifiers as case sensitive and as a result store them in mixed case?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsMultipleResultSets(self) -> bool:
        """
        Are multiple XResultSets from a single execute supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsMultipleTransactions(self) -> bool:
        """
        Can we have multiple transactions open at once (on different connections)?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsNonNullableColumns(self) -> bool:
        """
        Can columns be defined as non-nullable?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsOpenCursorsAcrossCommit(self) -> bool:
        """
        Can cursors remain open across commits?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsOpenCursorsAcrossRollback(self) -> bool:
        """
        Can cursors remain open across rollbacks?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsOpenStatementsAcrossCommit(self) -> bool:
        """
        Can statements remain open across commits?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsOpenStatementsAcrossRollback(self) -> bool:
        """
        Can statements remain open across rollbacks?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsOrderByUnrelated(self) -> bool:
        """
        Can an \"ORDER BY\" clause use columns not in the SELECT statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsOuterJoins(self) -> bool:
        """

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsPositionedDelete(self) -> bool:
        """
        Is positioned DELETE supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsPositionedUpdate(self) -> bool:
        """
        Is positioned UPDATE supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsResultSetConcurrency(self, setType: int, concurrency: int) -> bool:
        """
        Does the database support the concurrency type in combination with the given result set type?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsResultSetType(self, setType: int) -> bool:
        """
        Does the database support the given result set type?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSchemasInDataManipulation(self) -> bool:
        """
        Can a schema name be used in a data manipulation statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSchemasInIndexDefinitions(self) -> bool:
        """
        Can a schema name be used in an index definition statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSchemasInPrivilegeDefinitions(self) -> bool:
        """
        Can a schema name be used in a privilege definition statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSchemasInProcedureCalls(self) -> bool:
        """
        Can a schema name be used in a procedure call statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSchemasInTableDefinitions(self) -> bool:
        """
        Can a schema name be used in a table definition statement?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSelectForUpdate(self) -> bool:
        """
        Is SELECT for UPDATE supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsStoredProcedures(self) -> bool:
        """
        Are stored procedure calls using the stored procedure escape syntax supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSubqueriesInComparisons(self) -> bool:
        """
        Are subqueries in comparison expressions supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSubqueriesInExists(self) -> bool:
        """
        Are subqueries in \"exists\" expressions supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSubqueriesInIns(self) -> bool:
        """
        Are subqueries in \"in\" statements supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsSubqueriesInQuantifieds(self) -> bool:
        """
        Are subqueries in quantified expressions supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsTableCorrelationNames(self) -> bool:
        """
        Are table correlation names supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsTransactionIsolationLevel(self, level: int) -> bool:
        """
        Does this database support the given transaction isolation level?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsTransactions(self) -> bool:
        """
        support the Database transactions? If not, invoking the method com.sun.star.sdbc.XConnection.commit() is a noop and the isolation level is TransactionIsolation_NONE.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsTypeConversion(self) -> bool:
        """
        TRUE , if the Database supports the CONVERT function between SQL types, otherwise FALSE.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsUnion(self) -> bool:
        """
        Is SQL UNION supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def supportsUnionAll(self) -> bool:
        """
        Is SQL UNION ALL supported?

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updatesAreDetected(self, setType: int) -> bool:
        """
        indicates whether or not a visible row update can be detected by calling the method XResultSet.rowUpdated.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def usesLocalFilePerTable(self) -> bool:
        """
        use the database one local file to save for each table.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def usesLocalFiles(self) -> bool:
        """
        use the database local files to save the tables.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XDatabaseMetaData']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_completed_connection import XCompletedConnection as XCompletedConnection_98a0e46
from ..sdbc.x_data_source import XDataSource as XDataSource_a2990ae7
if typing.TYPE_CHECKING:
    from com.sun.star.ucb.RememberAuthentication import RememberAuthenticationProto  # type: ignore

class DatabaseAccessDataSource(XPropertySet_bc180bfa, XCompletedConnection_98a0e46, XDataSource_a2990ae7):
    """
    Service Class

    is a factory to create data access beans.
    
    Data access beans are shared among components, so if an already existing bean is requested, the existing one is returned.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API DatabaseAccessDataSource <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseAccessDataSource.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DatabaseAccessDataSource'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def PasswordMode(self) -> RememberAuthenticationProto:
        """
        determines the password handling.
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        locates the database access bean.
        """
        ...


__all__ = ['DatabaseAccessDataSource']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class DropCapFormat(object):
    """
    Struct Class

    This struct describes drop caps at a paragraph object.

    See Also:
        `API DropCapFormat <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1style_1_1DropCapFormat.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.DropCapFormat'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.style.DropCapFormat'
    """Literal Constant ``com.sun.star.style.DropCapFormat``"""

    def __init__(self, Lines: typing.Optional[int] = 0, Count: typing.Optional[int] = 0, Distance: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Lines (int, optional): Lines value.
            Count (int, optional): Count value.
            Distance (int, optional): Distance value.
        """
        super().__init__()

        if isinstance(Lines, DropCapFormat):
            oth: DropCapFormat = Lines
            self.Lines = oth.Lines
            self.Count = oth.Count
            self.Distance = oth.Distance
            return

        kargs = {
            "Lines": Lines,
            "Count": Count,
            "Distance": Distance,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._lines = kwargs["Lines"]
        self._count = kwargs["Count"]
        self._distance = kwargs["Distance"]


    @property
    def Lines(self) -> int:
        """
        This is the number of lines used for a drop cap.
        """
        return self._lines

    @Lines.setter
    def Lines(self, value: int) -> None:
        self._lines = value

    @property
    def Count(self) -> int:
        """
        This is the number of characters in the drop cap.
        """
        return self._count

    @Count.setter
    def Count(self, value: int) -> None:
        self._count = value

    @property
    def Distance(self) -> int:
        """
        This is the distance between the drop cap in the following text.
        """
        return self._distance

    @Distance.setter
    def Distance(self, value: int) -> None:
        self._distance = value


__all__ = ['DropCapFormat']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.document
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class CmisProperty(object):
    """
    Struct Class

    specifies a CMIS property.

    See Also:
        `API CmisProperty <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1document_1_1CmisProperty.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.CmisProperty'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.document.CmisProperty'
    """Literal Constant ``com.sun.star.document.CmisProperty``"""

    def __init__(self, Id: typing.Optional[str] = '', Name: typing.Optional[str] = '', Type: typing.Optional[str] = '', Updatable: typing.Optional[bool] = False, Required: typing.Optional[bool] = False, MultiValued: typing.Optional[bool] = False, OpenChoice: typing.Optional[bool] = False, Choices: typing.Optional[object] = None, Value: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Id (str, optional): Id value.
            Name (str, optional): Name value.
            Type (str, optional): Type value.
            Updatable (bool, optional): Updatable value.
            Required (bool, optional): Required value.
            MultiValued (bool, optional): MultiValued value.
            OpenChoice (bool, optional): OpenChoice value.
            Choices (object, optional): Choices value.
            Value (object, optional): Value value.
        """
        super().__init__()

        if isinstance(Id, CmisProperty):
            oth: CmisProperty = Id
            self.Id = oth.Id
            self.Name = oth.Name
            self.Type = oth.Type
            self.Updatable = oth.Updatable
            self.Required = oth.Required
            self.MultiValued = oth.MultiValued
            self.OpenChoice = oth.OpenChoice
            self.Choices = oth.Choices
            self.Value = oth.Value
            return

        kargs = {
            "Id": Id,
            "Name": Name,
            "Type": Type,
            "Updatable": Updatable,
            "Required": Required,
            "MultiValued": MultiValued,
            "OpenChoice": OpenChoice,
            "Choices": Choices,
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._id = kwargs["Id"]
        self._name = kwargs["Name"]
        self._type = kwargs["Type"]
        self._updatable = kwargs["Updatable"]
        self._required = kwargs["Required"]
        self._multi_valued = kwargs["MultiValued"]
        self._open_choice = kwargs["OpenChoice"]
        self._choices = kwargs["Choices"]
        self._value = kwargs["Value"]


    @property
    def Id(self) -> str:
        """
        unique ID of the Cmis property
        """
        return self._id

    @Id.setter
    def Id(self, value: str) -> None:
        self._id = value

    @property
    def Name(self) -> str:
        """
        specifies the display name of the CMIS property.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Type(self) -> str:
        """
        type of the property
        """
        return self._type

    @Type.setter
    def Type(self, value: str) -> None:
        self._type = value

    @property
    def Updatable(self) -> bool:
        """
        specifies if the property is updatable.
        """
        return self._updatable

    @Updatable.setter
    def Updatable(self, value: bool) -> None:
        self._updatable = value

    @property
    def Required(self) -> bool:
        """
        specifies if the property is required and can not be empty.
        """
        return self._required

    @Required.setter
    def Required(self, value: bool) -> None:
        self._required = value

    @property
    def MultiValued(self) -> bool:
        """
        specifies if the property has multiple value
        """
        return self._multi_valued

    @MultiValued.setter
    def MultiValued(self, value: bool) -> None:
        self._multi_valued = value

    @property
    def OpenChoice(self) -> bool:
        """
        specifies if the property value can be freely set or is restricted from a list of choices.
        """
        return self._open_choice

    @OpenChoice.setter
    def OpenChoice(self, value: bool) -> None:
        self._open_choice = value

    @property
    def Choices(self) -> object:
        """
        specifies the possible choices of the values.
        """
        return self._choices

    @Choices.setter
    def Choices(self, value: object) -> None:
        self._choices = value

    @property
    def Value(self) -> object:
        """
        specifies value of the property
        """
        return self._value

    @Value.setter
    def Value(self, value: object) -> None:
        self._value = value


__all__ = ['CmisProperty']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class DataPilotFieldGroupBy(object):
    """
    Const Class

    These constants select different types for grouping members of a DataPilot field by date or time.

    See Also:
        `API DataPilotFieldGroupBy <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupBy.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotFieldGroupBy'
    __ooo_type_name__: str = 'const'

    SECONDS = 1
    """
    Groups all members of a DataPilot field containing a date/time value by their current value for seconds.
    
    Example: The group :02 will contain all members that contain a time with a seconds value of 2, regardless of the date, hours and minutes of the member, e.g. 2002-Jan-03 00:00:02 or 1999-May-02 12:45:02.
    """
    MINUTES = 2
    """
    Groups all members of a DataPilot field containing a date/time value by their current value for minutes.
    
    Example: The group :02 will contain all members that contain a time with a minutes value of 2, regardless of the date, hours and seconds of the member, e.g. 2002-Jan-03 00:02:00 or 1999-May-02 12:02:45.
    """
    HOURS = 4
    """
    Groups all members of a DataPilot field containing a date/time value by their current value for hours.
    
    Example: The group 02 will contain all members that contain a time with a hour value of 2, regardless of the date, minutes and seconds of the member, e.g. 2002-Jan-03 02:00:00 or 1999-May-02 02:12:45.
    """
    DAYS = 8
    """
    Groups all members of a DataPilot field containing a date/time value by their calendar day, or by ranges of days.
    
    Examples:
    
    See descriptions for XDataPilotFieldGrouping.createDateGroup() for more details about day grouping.
    """
    MONTHS = 16
    """
    Groups all members of a DataPilot field containing a date/time value by their month.
    
    Example: The group Jan will contain all members with a date in the month January, regardless of the year, day, or time of the member, e.g. 2002-Jan-03 00:00:00 or 1999-Jan-02 02:12:45.
    """
    QUARTERS = 32
    """
    Groups all members of a DataPilot field containing a date/time value by their quarter.
    
    Example: The group Q1 will contain all members with a date in the first quarter of a year (i.e. the months January, February, and march), regardless of the year, day, or time of the member, e.g. 2002-Jan-03 00:00:00 or 1999-Mar-02 02:12:45.
    """
    YEARS = 64
    """
    Groups all members of a DataPilot field containing a date/time value by their year.
    
    Example: The group 1999 will contain all members with a date in the year 1999, regardless of the month, day, or time of the member, e.g. 1999-Jan-03 00:00:00 or 1999-May-02 02:12:45.
    """

__all__ = ['DataPilotFieldGroupBy']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...beans.named_value import NamedValue as NamedValue_a37a0af3
    from .x_digest_context import XDigestContext as XDigestContext_1b2b0ec5

class XDigestContextSupplier(XInterface_8f010a43):
    """
    This interface allows to get an object to generate a digest of a specified format.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XDigestContextSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XDigestContextSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.XDigestContextSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.XDigestContextSupplier'

    @abstractmethod
    def getDigestContext(self, nDigestID: int, aParams: typing.Tuple[NamedValue_a37a0af3, ...]) -> XDigestContext_1b2b0ec5:
        """
        returns an object that allows to generate the specified digest.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XDigestContextSupplier']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class CellFlags(object):
    """
    Const Class

    These constants select different types of cell contents.
    
    The values can be combined. They are used to insert, copy, or delete contents.

    See Also:
        `API CellFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.CellFlags'
    __ooo_type_name__: str = 'const'

    VALUE = 1
    """
    selects constant numeric values that are not formatted as dates or times.
    """
    DATETIME = 2
    """
    selects constant numeric values that have a date or time number format.
    """
    STRING = 4
    """
    selects constant strings.
    """
    ANNOTATION = 8
    """
    selects cell annotations.
    """
    FORMULA = 16
    """
    selects formulas.
    """
    HARDATTR = 32
    """
    selects all explicit formatting, but not the formatting which is applied implicitly through style sheets.
    """
    STYLES = 64
    """
    selects cell styles.
    """
    OBJECTS = 128
    """
    selects drawing objects.
    """
    EDITATTR = 256
    """
    selects formatting within parts of the cell contents.
    """
    FORMATTED = 512
    """
    selects cells with formatting within the cells or cells with more than one paragraph within the cells.
    """

__all__ = ['CellFlags']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..table.table_sort_descriptor import TableSortDescriptor as TableSortDescriptor_18ef0ebf
if typing.TYPE_CHECKING:
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56

class SheetSortDescriptor(TableSortDescriptor_18ef0ebf):
    """
    Service Class

    a description of how a cell range is to be sorted.
    
    This service extends the com.sun.star.table.TableSortDescriptor service with spreadsheet specific properties.

    See Also:
        `API SheetSortDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SheetSortDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BindFormatsToContent(self) -> bool:
        """
        specifies if cell formats are moved with the contents they belong to.
        """
        ...

    @abstractproperty
    def CopyOutputData(self) -> bool:
        """
        specifies if the sorted data should be copied to another position in the document.
        """
        ...

    @abstractproperty
    def IsUserListEnabled(self) -> bool:
        """
        specifies if a user defined sorting list is used.
        """
        ...

    @abstractproperty
    def OutputPosition(self) -> CellAddress_ae5f0b56:
        """
        specifies the position where sorted data are to be copied.
        
        This property is only used, if SheetSortDescriptor.CopyOutputData is TRUE.
        """
        ...

    @abstractproperty
    def UserListIndex(self) -> int:
        """
        specifies which user defined sorting list is used.
        
        This property is only used, if SheetSortDescriptor.IsUserListEnabled is TRUE.
        """
        ...


__all__ = ['SheetSortDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation
from __future__ import annotations
import typing
from abc import abstractmethod
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_presentation import XPresentation as XPresentation_30890f78
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_slide_show_controller import XSlideShowController as XSlideShowController_a55c1232

class XPresentation2(XPropertySet_bc180bfa, XPresentation_30890f78):
    """
    enhances the XPresentation interface to give access to a XSlideShowController and to start a presentation with arguments.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XPresentation2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1presentation_1_1XPresentation2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.XPresentation2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.presentation.XPresentation2'

    @abstractmethod
    def getController(self) -> XSlideShowController_a55c1232:
        """
        if the slide show is running, this returns a controller object to control the running slide show.
        """
        ...
    @abstractmethod
    def isRunning(self) -> bool:
        """
        returns true if the slide show is currently running
        """
        ...
    @abstractmethod
    def startWithArguments(self, Arguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        start the slide show with the given arguments.
        
        All arguments override the values from Presentation.
        """
        ...

__all__ = ['XPresentation2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations


class EventTrigger(object):
    """
    Const Class


    See Also:
        `API EventTrigger <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1EventTrigger.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.EventTrigger'
    __ooo_type_name__: str = 'const'

    NONE = 0
    """
    Nothing triggers this event.
    """
    ON_BEGIN = 1
    ON_END = 2
    BEGIN_EVENT = 3
    """
    This event is raised when the element local timeline begins to play.
    
    It will be raised each time the element begins the active duration (i.e. when it restarts, but not when it repeats).
    """
    END_EVENT = 4
    """
    This event is raised at the active end of the element.
    
    Note that this event is not raised at the simple end of each repeat.
    """
    ON_CLICK = 5
    ON_DBL_CLICK = 6
    ON_MOUSE_ENTER = 7
    ON_MOUSE_LEAVE = 8
    ON_NEXT = 9
    """
    This event is raised when the user wants the presentation to go one step forward.
    """
    ON_PREV = 10
    """
    This event is raised when the user wants the presentation to go one step backward.
    """
    ON_STOP_AUDIO = 11
    REPEAT = 12
    """
    This event is raised when the element local timeline repeats.
    
    It will be raised each time the element repeats, after the first iteration.
    """

__all__ = ['EventTrigger']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6

class XStruct(XInterface_8f010a43):
    """
    is used for the standard mapping for a SQL structured type.
    
    A Struct object contains a value for each attribute of the SQL structured type that it represents. By default, an instance of Struct is valid as long as the application has a reference to it.

    See Also:
        `API XStruct <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XStruct.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XStruct'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XStruct'

    @abstractmethod
    def getAttributes(self, typeMap: XNameAccess_e2ab0cf6) -> typing.Tuple[object, ...]:
        """
        produces the ordered values of the attributes of the SQL structured type that this Struct object represents.
        
        This method uses the given type map for customizations of the type mappings. If there is no entry in the given type map that matches or the given type map is NULL , the structured type that this Struct object represents, the driver uses the connection type mapping.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getSQLTypeName(self) -> str:
        """
        retrieves the SQL type name of the SQL structured type that this Struct object represents.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XStruct']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_simple_text import XSimpleText as XSimpleText_a5ca0b34
if typing.TYPE_CHECKING:
    from .x_text_content import XTextContent as XTextContent_b16e0ba5
    from .x_text_range import XTextRange as XTextRange_9a910ab7

class XText(XSimpleText_a5ca0b34):
    """
    extends a XSimpleText by the capability of inserting XTextContents.

    See Also:
        `API XText <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XText.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XText'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XText'

    @abstractmethod
    def insertTextContent(self, xRange: XTextRange_9a910ab7, xContent: XTextContent_b16e0ba5, bAbsorb: bool) -> None:
        """
        inserts a content, such as a text table, text frame or text field.
        
        Which contents are accepted is implementation-specific. Some implementations may only accept contents which were created by the factory that supplied the same text or the document which contains the text.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def removeTextContent(self, xContent: XTextContent_b16e0ba5) -> None:
        """
        removes the specified content from the text object.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XText']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class LineBreakUserOptions(object):
    """
    Struct Class

    Line break options passed in calls to XBreakIterator.getLineBreak().

    See Also:
        `API LineBreakUserOptions <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1LineBreakUserOptions.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.LineBreakUserOptions'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.LineBreakUserOptions'
    """Literal Constant ``com.sun.star.i18n.LineBreakUserOptions``"""

    def __init__(self, forbiddenBeginCharacters: typing.Optional[str] = '', forbiddenEndCharacters: typing.Optional[str] = '', applyForbiddenRules: typing.Optional[bool] = False, allowPunctuationOutsideMargin: typing.Optional[bool] = False, allowHyphenateEnglish: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            forbiddenBeginCharacters (str, optional): forbiddenBeginCharacters value.
            forbiddenEndCharacters (str, optional): forbiddenEndCharacters value.
            applyForbiddenRules (bool, optional): applyForbiddenRules value.
            allowPunctuationOutsideMargin (bool, optional): allowPunctuationOutsideMargin value.
            allowHyphenateEnglish (bool, optional): allowHyphenateEnglish value.
        """
        super().__init__()

        if isinstance(forbiddenBeginCharacters, LineBreakUserOptions):
            oth: LineBreakUserOptions = forbiddenBeginCharacters
            self.forbiddenBeginCharacters = oth.forbiddenBeginCharacters
            self.forbiddenEndCharacters = oth.forbiddenEndCharacters
            self.applyForbiddenRules = oth.applyForbiddenRules
            self.allowPunctuationOutsideMargin = oth.allowPunctuationOutsideMargin
            self.allowHyphenateEnglish = oth.allowHyphenateEnglish
            return

        kargs = {
            "forbiddenBeginCharacters": forbiddenBeginCharacters,
            "forbiddenEndCharacters": forbiddenEndCharacters,
            "applyForbiddenRules": applyForbiddenRules,
            "allowPunctuationOutsideMargin": allowPunctuationOutsideMargin,
            "allowHyphenateEnglish": allowHyphenateEnglish,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._forbidden_begin_characters = kwargs["forbiddenBeginCharacters"]
        self._forbidden_end_characters = kwargs["forbiddenEndCharacters"]
        self._apply_forbidden_rules = kwargs["applyForbiddenRules"]
        self._allow_punctuation_outside_margin = kwargs["allowPunctuationOutsideMargin"]
        self._allow_hyphenate_english = kwargs["allowHyphenateEnglish"]


    @property
    def forbiddenBeginCharacters(self) -> str:
        """
        Characters not allowed at the beginning of a line.
        """
        return self._forbidden_begin_characters

    @forbiddenBeginCharacters.setter
    def forbiddenBeginCharacters(self, value: str) -> None:
        self._forbidden_begin_characters = value

    @property
    def forbiddenEndCharacters(self) -> str:
        """
        Characters not allowed at the end of a line.
        """
        return self._forbidden_end_characters

    @forbiddenEndCharacters.setter
    def forbiddenEndCharacters(self, value: str) -> None:
        self._forbidden_end_characters = value

    @property
    def applyForbiddenRules(self) -> bool:
        """
        If the forbidden characters rules are to be applied or not.
        """
        return self._apply_forbidden_rules

    @applyForbiddenRules.setter
    def applyForbiddenRules(self, value: bool) -> None:
        self._apply_forbidden_rules = value

    @property
    def allowPunctuationOutsideMargin(self) -> bool:
        """
        If punctuation characters are allowed at the end of the line if outside of the margins, resulting in a line not being wrapped if only the punctuation would wrap.
        """
        return self._allow_punctuation_outside_margin

    @allowPunctuationOutsideMargin.setter
    def allowPunctuationOutsideMargin(self, value: bool) -> None:
        self._allow_punctuation_outside_margin = value

    @property
    def allowHyphenateEnglish(self) -> bool:
        """
        Allow English hyphenation.
        """
        return self._allow_hyphenate_english

    @allowHyphenateEnglish.setter
    def allowHyphenateEnglish(self, value: bool) -> None:
        self._allow_hyphenate_english = value


__all__ = ['LineBreakUserOptions']
